/*
 * @Author: Yujialong
 * @Date: 2021-11-03 14:33:21
 * @LastEditTime: 2021-12-22 09:41:33
 */
/**
 * 业务配置
 * */

const env = process.env.NODE_ENV;

const Setting = {
    /**
     * 基础配置
     * */
    // 网页标题的后缀
    titleSuffix: '数据前瞻',
    // 路由模式，可选值为 history 或 hash
    routerMode: 'hash',
    // 页面切换时，是否显示模拟的进度条
    showProgressBar: true,
    /**
     * 接口地址
     * 测试：http://39.108.250.202:9000
     * 正式：http://www.dataforward.cn:9000
     * */
    // apiBaseURL: env === 'development' ? 'http://192.168.31.151:9000' : 'http://39.108.250.202:9000',
    apiBaseURL: env === 'development' ? 'http://192.168.31.151:9000/' : `${location.origin}:9000/`,
    // 加密货币接口地址
    cryptoBaseURL: `http://159.138.53.111/`,
    // 接口请求返回错误时，弹窗的持续时间，单位：秒
    modalDuration: 3,
    // 接口请求返回错误时，弹窗的类型，可选值为 Message 或 Notice
    errorModalType: 'Message',
    // Cookies 默认保存时间，单位：天
    cookiesExpires: 1,
    // 长时间未操作，自动退出登录时间
    autoLogoutTime: 3600000,
    /**
     * localStorage里保存的token的key
     */
    tokenKey: 'data_token',
    /**
     * localStorage里保存的vuex的key
     */
    storeKey: 'data_store',
    /**
     * 默认密码
     */
    initialPassword: '111aaa',
    /**
     * 所属平台：1->职站 2->数据平台 3->中台
     */
    platformId: 2,
    /**
     * 平台端区分：0->教师端 1->学生端 2->无端
     */
    platformType: 2,
    /**
    * 多语言配置
    * */
    i18n: {
        // 默认语言
        default: 'zh',
        // 是否根据用户电脑配置自动设置语言（仅第一次有效）
        auto: false
    },
    /**
     * 布局配置
     * */
    layout: {
        
    },
    /**
     * 功能配置
     * */
    // 相同路由，不同参数间进行切换，是否强力更新
    sameRouteForceUpdate: false,
    // 是否使用动态路由
    dynamicRoute: true,
    // 文件上传
    upload: {
        apiURL: 'http://8.134.8.197:8001',
        maxSize: 30,
    },
};

export default Setting;
